#define BLOCK 256

kernel void normalizeKernel(int Cwidth, int Cheight, __global float* Celements)
{

	int row = get_global_id(1);
	int col = get_global_id(0);

	Celements[row * Cwidth + col] =  Celements[row * Cwidth + col] * (1.f / (Cwidth * Cheight));

}

kernel void absComplexInterleaved(int Cwidth, int Cheight, __global float* Celements)
{

	int row = get_global_id(1);
	int col = get_global_id(0);

	float a = Celements[row * Cwidth * 2 + col * 2];
	float b = Celements[row * Cwidth * 2 + col * 2 + 1];

	Celements[row * Cwidth * 2 + col * 2] =  a * a + b * b;
	Celements[row * Cwidth * 2 + col * 2 + 1] = 0.f;
}

// prepared data for (i)fft. Dim Specifies whether row or column vector halves are
// being swapped
kernel void fftshift(int Cwidth, int Cheight, __global float* Celements, __global float* data_out, int dim)
{

	int row = get_global_id(1);
	int col = get_global_id(0);

	float tempReal = 0.f;
	float tempImag = 0.f;

	if (dim == 0)
	{
		if (col < (Cwidth / 2))
		{
			data_out[row * Cwidth * 2 + col * 2] = Celements[row * Cwidth * 2 + col * 2 + Cwidth];
			data_out[row * Cwidth * 2 + col * 2 + 1] = Celements[row * Cwidth * 2 + col * 2 + 1 + Cwidth];
			
			data_out[row * Cwidth * 2 + col * 2 + Cwidth] = Celements[row * Cwidth * 2 + col * 2];
			data_out[row * Cwidth * 2 + col * 2 + 1 + Cwidth] = Celements[row * Cwidth * 2 + col * 2 + 1];
		}
	}

	else if (dim == 1)
	{
		if (row < Cheight / 2)
		{

			data_out[row * Cwidth * 2 + col * 2] = Celements[(row + Cheight / 2) * Cwidth * 2 + col * 2];
			data_out[row * Cwidth * 2 + col * 2 + 1] = Celements[(row + Cheight / 2) * Cwidth * 2 + col * 2 + 1];

			data_out[(row + Cheight / 2) * Cwidth * 2 + col * 2] = Celements[row * Cwidth * 2 + col * 2];
			data_out[(row + Cheight / 2) * Cwidth * 2 + col * 2 + 1] = Celements[row * Cwidth * 2 + col * 2 + 1];
		}
	}
}

kernel void convolutionLocal(int Cwidth, int Cheight, int decimFactor, int numCoeff, 
							__global float *Celements, __global float *output, __global float* filter,
							__local float *blockr,
							__local float *blocki)
{
	int row = get_global_id(1);
	int col = get_global_id(0);

	float sumr = 0.f;
	float sumi = 0.f;



	output[row * 2 * Cwidth + 2 * col] = 1.f * get_local_size(0);
	output[row * 2 * Cwidth + 2 * col + 1] = 1.f * get_local_size(1);
}

